Ouster SDK Mapping
==================

..
    [sdk-mapping-overview-start]

The Ouster SDK Mapping provides mapping functionalities as an extension of the
Ouster Sensor SDK `PyPI`_

The two main functions of the Ouster SDK Mapping:

* Simultaneous Localization and Mapping (SLAM)
* Point Cloud Construction using SLAM outputs

More SDK libraries and tools information can be found at `GitHub`_ and Ouster SDK
Mapping user documentation is located at `MappingSession`_

..
    [sdk-mapping-overview-end]

Supported Platforms
-------------------

..
    [supported-platforms-start]

Ouster SDK Mapping is a pure python package which can be installed on all platforms.
However, some of its dependencies may not be supported on your system.

SLAM function is available on the following platforms:

* Linux x86_64 (``manylinux2014_x86_64``) for python >= 3.8, <=3.12
* MacOS >= 10.14 on x86_64 platforms (``macosx_10_14_x86_64``) for python >= 3.8, <=3.12
* MacOS >= 11.0 on M1 platforms (``macosx_11_0_arm64``) for python >= 3.8, <=3.12
* Windows 10 on x86_64 platforms (``win_amd64``) for python >= 3.8, <=3.12

* NOT support Linux ARM64 platforms (``manylinux2014_aarch64``)


Point Cloud Construction is available on the following platforms:

* Linux x86_64 (``manylinux2014_x86_64``) for python >= 3.8, <=3.11
* Linux ARM64 (``manylinux2014_aarch64``) for python >= 3.8, <=3.11
* MacOS >= 10.14 on x86_64 platforms (``macosx_10_14_x86_64``) for python >= 3.8, <=3.12
* MacOS >= 11.0 on M1 platforms (``macosx_11_0_arm64``) for python >= 3.8, <=3.12
* Windows 10 on x86_64 platforms (``win_amd64``) for python >= 3.8, <=3.11


Later we will support building from source.

.. _PyPI: https://pypi.org/project/ouster-sdk/
.. _GitHub: https://github.com/ouster-lidar/ouster_example/
.. _MappingSession: https://static.ouster.dev/sdk-docs/cli/mapping-sessions.html

..
    [supported-platforms-end]
